==> order-api-lm-1.1.66-20241210.091711-2-sources.jar: com/elitesland/yst/lm/order/rpc/LmSaleDoRpcService.java <==
package com.elitesland.yst.lm.order.rpc;

import com.elitesland.yst.lm.order.Application;
import com.elitesland.yst.lm.order.rpc.param.query.LmSalDoQueryDTO;
import com.elitesland.yst.lm.order.rpc.param.query.LmUnShippedQueryDTO;
import com.elitesland.yst.lm.order.rpc.param.resp.LmSalDoPerforRespDTO;
import com.elitesland.yst.lm.order.rpc.param.resp.LmSalDoRespDTO;
import com.elitesland.yst.lm.order.rpc.param.resp.LmUnShippedRespDTO;
import com.elitesland.yst.lm.order.rpc.param.resp.VehicleNoInfoVO;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;

/**
 * @Author: ryan.xu
 * @since 2023/3/25
 */
@FeignClient(name = Application.NAME, path = LmSaleDoRpcService.URI)
@Validated
public interface LmSaleDoRpcService {

    String URI = Application.URI_PREFIX + "/salDo";

    /**
     * 发货单查询
     *
     * @param param
     * @return
     */
    @PostMapping("/query")
    LmSalDoRespDTO querySalDo(@RequestBody LmSalDoQueryDTO param);

    /**
     * 未发货单查询
     *
     * @param param
     * @return
     */
    @PostMapping("/unShipped/query")
    LmUnShippedRespDTO queryUnShippedOrder(@RequestBody LmUnShippedQueryDTO param);

    /**
     * 查询销售业绩统计数据
     * @param dateStr
     * @return
     */
    @PostMapping("/querySalePerfor")
    List<LmSalDoPerforRespDTO> querySalePerfor(@RequestParam("dateStr") String dateStr);

    /**
     * 根据车架号查询发货单车辆信息
     * @param vehicleNo
     * @return
     */
    @PostMapping("/queryVehicleNoInfo")
    VehicleNoInfoVO queryVehicleNoInfo(@RequestParam("vehicleNo") String vehicleNo);

    @PostMapping("/vehicleBelongCust")
    Boolean vehicleBelongCust(@RequestParam("vehicleNo") String vehicleNo, @RequestParam("custCode") String custCode);

    @PostMapping("/vehicleBelongCustList")
    List<String> vehicleBelongCustList(@RequestParam("vehicleNo") String vehicleNo);
    @GetMapping("/getLogisNo")
    String getLogisNo(@RequestParam("docNo") String docNo);
}

==> order-api-lm-5.0.1.17-20251115.013829-6-sources.jar: com/elitesland/yst/lm/order/rpc/LmSaleDoRpcService.java <==
package com.elitesland.yst.lm.order.rpc;

import com.elitesland.yst.lm.order.Application;
import com.elitesland.yst.lm.order.rpc.param.query.LmSalDoQueryDTO;
import com.elitesland.yst.lm.order.rpc.param.query.LmUnShippedQueryDTO;
import com.elitesland.yst.lm.order.rpc.param.resp.*;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;

/**
 * @Author: ryan.xu
 * @since 2023/3/25
 */
@FeignClient(name = Application.NAME, path = LmSaleDoRpcService.URI)
@Validated
public interface LmSaleDoRpcService {

    String URI = Application.URI_PREFIX + "/salDo";

    /**
     * 发货单查询
     *
     * @param param
     * @return
     */
    @PostMapping("/query")
    LmSalDoRespDTO querySalDo(@RequestBody LmSalDoQueryDTO param);

    /**
     * 未发货单查询
     *
     * @param param
     * @return
     */
    @PostMapping("/unShipped/query")
    LmUnShippedRespDTO queryUnShippedOrder(@RequestBody LmUnShippedQueryDTO param);
    @PostMapping("/Shipped/query")
    LmShippedRespDTO queryShippedOrder(@RequestBody LmUnShippedQueryDTO param);

    /**
     * 查询销售业绩统计数据
     * @param dateStr
     * @return
     */
    @PostMapping("/querySalePerfor")
    List<LmSalDoPerforRespDTO> querySalePerfor(@RequestParam("dateStr") String dateStr);

    /**
     * 根据车架号查询发货单车辆信息
     * @param vehicleNo
     * @return
     */
    @PostMapping("/queryVehicleNoInfo")
    VehicleNoInfoVO queryVehicleNoInfo(@RequestParam("vehicleNo") String vehicleNo);

    @PostMapping("/vehicleBelongCust")
    Boolean vehicleBelongCust(@RequestParam("vehicleNo") String vehicleNo, @RequestParam("custCode") String custCode);

    @PostMapping("/vehicleBelongCustList")
    List<String> vehicleBelongCustList(@RequestParam("vehicleNo") String vehicleNo);
    @GetMapping("/getLogisNo")
    String getLogisNo(@RequestParam("docNo") String docNo);
    @PostMapping("/getLogisticInfo")
    List<LogisticInfoVO> getLogisticInfo(@RequestBody List<String> docNos);
}
